#  SAP LeanIX for Application and Business Owners
### On this page
  * [Access the Workspace](https://help.sap.com/docs/leanix/ea/for-application-and-business-owners#access-the-workspace)
  * [Find Information from Fact Sheets](https://help.sap.com/docs/leanix/ea/for-application-and-business-owners#find-information-from-fact-sheets)
  * [Contribute Data to Fact Sheets](https://help.sap.com/docs/leanix/ea/for-application-and-business-owners#contribute-data-to-fact-sheets)
  * [Next Steps](https://help.sap.com/docs/leanix/ea/for-application-and-business-owners#next-steps)


First steps in using SAP LeanIX for application and business owners.
Enterprise Architecture Management is a collaborative effort. Various stakeholders, such as Application Owners, Business Owners, Data Architects, Product and Project Managers, etc, all play an important role in contributing relevant information to EAs. They ensure Fact Sheets contain accurate and up-to-date information by updating relevant attributes, dependencies, and relationships.
Notably, the roles of Application Owners and Business Owners are particularly significant. As a contributor, it is important to learn how to access the Fact Sheets you are responsible for, fill and access information in them, and become familiar with collaboration features. These essentials will help you get started effectively.
To start, familiarize yourself with SAP LeanIX application layout and navigation. Go through Introduction to SAP LeanIX if you haven’t already.
